@@ -5,6 +5,10 @@ from ..record import Record, JsonData
 import requests
 import logging
 import time
+from copy import deepcopy
+import re
+from json import JSONDecodeError
+from lxml import etree
 
 
 def fetch_users(q: str, zone: str, env: Optional[Literal['P', 'S']] = 'P') -> List[userslib.User]:
@@ -68,7 +72,7 @@ def fetch_user_in_all_iz(primary_id: str, env: Optional[Literal['P', 'S']] = 'P'
     :return: list of :class:`almapiwrapper.users.User`
     """
 
-    list_iz = ApiKeys().get_iz_codes()
+    list_iz = ApiKeys().get_iz_codes(env=env)
     users = []
     for iz in list_iz:
         users_temp = fetch_users(f'primary_id~{primary_id}', iz, env)
@@ -119,6 +123,60 @@ def check_synchro(nz_users: Union[List[userslib.User], userslib.User]) -> Option
 
     return not_synchro_iz_users
 
+def force_synchro(nz_users: Union[List[userslib.User], userslib.User]) -> List[str]:
+    """Force synchronization of a NZ user with copies of the account across IZs.
+    :param nz_users: list of :class:`almapiwrapper.users.User` or only one :class:`almapiwrapper.users.User`
+    :return: list of errors
+    """
+
+    error_msg = []
+
+    if type(nz_users) is not list:
+        nz_users = [nz_users]
+
+    nb_users = len(nz_users)
+    nz_users = [user for user in nz_users if user.zone == 'NZ']
+
+    if len(nz_users) < nb_users:
+        logging.error(f'Impossible to force synchronization on not NZ account')
+        error_msg.append(f'Impossible to force synchronization on not NZ account')
+        return error_msg
+
+    for nz_user in nz_users:
+
+        iz_users = fetch_user_in_all_iz(nz_user.primary_id, nz_user.env)
+        _ = iz_users
+
+        for iz_user in iz_users:
+            iz_user.save()
+
+            # Copy contact_info
+            iz_user.data['contact_info'] = deepcopy(nz_user.data['contact_info'])
+
+            # Copy identifiers
+            nz_ids = [nz_id['value'] for nz_id in nz_user.data['user_identifier']]
+            local_ids = [u_id for u_id in iz_user.data['user_identifier'] if
+                         u_id['value'] not in nz_ids and u_id['id_type']['value'] == '03']
+            iz_user.data['user_identifier'] = local_ids + nz_user.data['user_identifier']
+    
+            # Copy notes
+            local_notes = [u_note for u_note in iz_user.data['user_note'] if u_note['segment_type'] == 'Internal']
+            iz_user.data['user_note'] = local_notes + nz_user.data['user_note']
+    
+            # Copy user_group
+            nz_user_group = nz_user.data['user_group']['value']
+            local_user_group = iz_user.data['user_group']['value']
+            if re.match(r'\d{2}', nz_user_group):
+                if re.match(r'\d{2}', local_user_group):
+                    iz_user.data['user_group']['value'] = nz_user_group
+            else:
+                if re.match(r'\d{2}', local_user_group):
+                    iz_user.data['user_group']['value'] = nz_user_group
+            iz_user.update(override=['user_group'])
+            if iz_user.error is True:
+                error_msg.append(f'{repr(iz_user)}: error on update / {iz_user.error_msg}')
+
+    return error_msg
 
 def _handle_error(q: str, r: requests.models.Response, msg: str, zone: str, env: str):
     """Set the record error attribute to True and write the logs about the error
@@ -127,8 +185,12 @@ def _handle_error(q: str, r: requests.models.Response, msg: str, zone: str, env:
     :param msg: context message of the error
     :return: None
     """
-    json_data = r.json()
-    error_message = json_data['errorList']['error'][0]['errorMessage']
+    try:
+        json_data = r.json()
+        error_message = json_data['errorList']['error'][0]['errorMessage']
+    except JSONDecodeError:
+        xml = etree.fromstring(r.content)
+        error_message = xml.find('.//{http://com/exlibris/urm/general/xmlbeans}errorMessage').text
 
     logging.error(f'fetch_users({q}, {zone}, {env}) - {r.status_code}: '
                   f'{msg} / {error_message}')
